@@ -70,7 +70,7 @@ class GreenSSLSocket(_original_sslsocket):
                         sock=sock.fd,
                         server_side=server_side,
                         do_handshake_on_connect=False,
-                        suppress_ragged_eofs=kw.get('suppress_ragged_eofs'),
+                        suppress_ragged_eofs=kw.get('suppress_ragged_eofs', True),
                         server_hostname=kw.get('server_hostname'),
                         context=context,
                         session=kw.get('session'),
@@ -404,14 +404,11 @@ class GreenSSLSocket(_original_sslsocket):
 
         new_ssl = type(self)(
             newsock,
-            keyfile=self.keyfile,
-            certfile=self.certfile,
             server_side=True,
-            cert_reqs=self.cert_reqs,
-            ssl_version=self.ssl_version,
-            ca_certs=self.ca_certs,
             do_handshake_on_connect=False,
-            suppress_ragged_eofs=self.suppress_ragged_eofs)
+            suppress_ragged_eofs=self.suppress_ragged_eofs,
+            _context=self._context,
+        )
         return (new_ssl, addr)
 
     def dup(self):
